#
# spec file for package ca-certificates-mozilla
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define certdir %{trustdir_static}
BuildRequires:  p11-kit-devel

BuildRequires:  ca-certificates
BuildRequires:  openssl
BuildRequires:  python

Name:           ca-certificates-mozilla
# Version number is NSS_BUILTINS_LIBRARY_VERSION in this file:
# http://hg.mozilla.org/projects/nss/file/default/lib/ckfw/builtins/nssckbi.h
Version:        2.26
Release:        18.1
Summary:        CA certificates for OpenSSL
License:        MPL-2.0
Group:          Productivity/Networking/Security
Url:            http://www.mozilla.org
# IMPORTANT: procedure to update certificates:
# - Check the log of the cert file:
#   http://hg.mozilla.org/projects/nss/log/default/lib/ckfw/builtins/certdata.txt
# - download the new certdata.txt
#   wget -O certdata.txt "http://hg.mozilla.org/projects/nss/file/default/lib/ckfw/builtins/certdata.txt"
# - run compareoldnew to show fingerprints of new and changed certificates
# - check the bugs referenced in hg log and compare the checksum
#   to output of compareoldnew
# - Watch out that blacklisted or untrusted certificates are not
#   accidentally included!
Source:         http://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/certdata.txt
Source1:        http://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/nssckbi.h
# from Fedora. Note: currently contains extra fix to remove quotes. Pending upstream approval.
Source10:       certdata2pem.py
Source11:       %{name}.COPYING
Source12:       compareoldnew
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
# for update-ca-certificates
Requires(post):    ca-certificates
Requires(postun):  ca-certificates
#
# replaces this package from SLE11 times
Obsoletes:      openssl-certs

%description
This package contains some CA root certificates for OpenSSL extracted
from MozillaFirefox



%prep
%setup -qcT

/bin/cp %{SOURCE0} .

install -m 644 %{SOURCE11} COPYING
ver=`sed -ne '/NSS_BUILTINS_LIBRARY_VERSION /s/.*"\(.*\)"/\1/p' < "%{SOURCE1}"`
if [ "%{version}" != "$ver" ]; then
	echo "*** Version number mismatch: spec file should be version $ver"
	false
fi

%build
python %{SOURCE10}

%install
mkdir -p %{buildroot}/%{trustdir_static}/anchors
set +x
for i in *.crt; do
	args=()
	trust=`sed -n '/^# openssl-trust=/{s/^.*=//;p;q;}' "$i"`
	distrust=`sed -n '/^# openssl-distrust=/{s/^.*=//;p;q;}' "$i"`
	alias=`sed -n '/^# alias=/{s/^.*=//;p;q;}' "$i"`
	args+=('-trustout')
	for t in $trust; do
		args+=("-addtrust" "$t")
	done
	for t in $distrust; do
		args+=("-addreject" "$t")
	done
	[ -z "$alias" ] || args+=('-setalias' "$alias")

	echo "$i ${args[*]}"
	fname="%{buildroot}/%{trustdir_static}$d/${i%%:*}.pem"
	if [ -e "$fname" ]; then
		fname="${fname%.pem}"
		j=1
		while [ -e "$fname.$j.pem" ]; do
			j=$((j+1))
		done
		fname="$fname.$j.pem"
	fi
	{
		grep '^#' "$i"
		openssl x509 -in "$i" "${args[@]}"
	} > "$fname"
done
for i in *.p11-kit ; do
	install -m 644 "$i" "%{buildroot}/%{trustdir_static}"
done
set -x

%post
update-ca-certificates || true

%postun
update-ca-certificates || true

%files
%defattr(-, root, root)
%doc COPYING
%{trustdir_static}

%changelog
* Thu Aug 16 2018 meissner@suse.com
- updated to 2.26 state of the Mozilla NSS Certificate store. (bsc#1104780)
  - removed server auth
  - Certplus Root CA G1
  - Certplus Root CA G2
  - OpenTrust Root CA G1
  - OpenTrust Root CA G2
  - OpenTrust Root CA G3
  - remove CA
  - ComSign CA
  - added new CA
  - GlobalSign
* Fri Jul  6 2018 meissner@suse.com
- Updated to 2.24 state of the Mozilla NSS Certificate store.
- Removed CAs:
  * S-TRUST_Universal_Root_CA:2.16.96.86.197.75.35.64.91.100.212.237.37.218.217.214.30.30.crt
  * TC_TrustCenter_Class_3_CA_II:2.14.74.71.0.1.0.2.229.160.93.214.63.0.81.191.crt
  * TÜRKTRUST_Elektronik_Sertifika_Hizmet_Sağlayıcısı_H5:2.7.0.142.23.254.36.32.129.crt
* Wed Jan 24 2018 meissner@suse.com
- Updated to Mozilla certificate version 2.22 (bsc#1071152 bsc#1071390 bsc#1010996)
- diff-from-upstream-2.7.patch: removed the old 1024 bit CAs we temporary
  left in to allow in-chain root certificates as openssl is now able to handle it.
- Removed Code Signing rights from a lot of CAs (not listed here).
- Removed Server Auth rights from:
  * AddTrust Low-Value Services Root
  * Camerfirma Chambers of Commerce Root
  * Camerfirma Global Chambersign Root
  * Swisscom Root CA 2
- Removed fully:
  * AddTrust Public Services Root
  * AddTrust Public CA Root
  * AddTrust Qualified CA Root
  * ApplicationCA - Japanese Government
  * Buypass Class 2 CA 1
  * CA Disig Root R1
  * CA WoSign ECC Root
  * Certification Authority of WoSign G2
  * Certinomis - Autorité Racine
  * Certum Root CA
  * China Internet Network Information Center EV Certificates Root
  * CNNIC ROOT
  * Comodo Secure Services root
  * Comodo Trusted Services root
  * ComSign Secured CA
  * EBG Elektronik Sertifika Hizmet Sağlayıcısı
  * Equifax Secure CA
  * Equifax Secure eBusiness CA 1
  * Equifax Secure Global eBusiness CA
  * GeoTrust Global CA 2
  * IGC/A
  * Juur-SK
  * Microsec e-Szigno Root CA
  * PSCProcert
  * Root CA Generalitat Valenciana
  * RSA Security 2048 v3
  * Security Communication EV RootCA1
  * Sonera Class 1 Root CA
  * StartCom Certification Authority
  * StartCom Certification Authority G2
  * S-TRUST Authentication and Encryption Root CA 2005 PN
  * Swisscom Root CA 1
  * Swisscom Root EV CA 2
  * TÜBİTAK UEKAE Kök Sertifika Hizmet Sağlayıcısı - Sürüm 3
  * TÜRKTRUST Elektronik Sertifika Hizmet Sağlayıcısı
  * TÜRKTRUST Elektronik Sertifika Hizmet Sağlayıcısı H6
  * UTN USERFirst Hardware Root CA
  * UTN USERFirst Object Root CA
  * VeriSign Class 3 Secure Server CA - G2
  * Verisign Class 1 Public Primary Certification Authority
  * Verisign Class 2 Public Primary Certification Authority - G2
  * Verisign Class 3 Public Primary Certification Authority
  * WellsSecure Public Root Certificate Authority
  * Certification Authority of WoSign
  * WoSign China
- Added:
  * Amazon Root CA 1: (email protection, server auth)
  * Amazon Root CA 2: (email protection, server auth)
  * Amazon Root CA 3: (email protection, server auth)
  * Amazon Root CA 4: (email protection, server auth)
  * Certplus Root CA G1: (email protection, server auth)
  * Certplus Root CA G2: (email protection, server auth)
  * D-TRUST Root CA 3 2013: (email protection)
  * GDCA TrustAUTH R5 ROOT: (server auth)
  * Hellenic Academic and Research Institutions ECC RootCA 2015: (email protection, server auth)
  * Hellenic Academic and Research Institutions RootCA 2015: (email protection, server auth)
  * ISRG Root X1: (server auth)
  * LuxTrust Global Root 2: (server auth)
  * OpenTrust Root CA G1: (email protection, server auth)
  * OpenTrust Root CA G2: (email protection, server auth)
  * OpenTrust Root CA G3: (email protection, server auth)
  * SSL.com EV Root Certification Authority ECC: (server auth)
  * SSL.com EV Root Certification Authority RSA R2: (server auth)
  * SSL.com Root Certification Authority ECC: (email protection, server auth)
  * SSL.com Root Certification Authority RSA: (email protection, server auth)
  * Symantec Class 1 Public Primary Certification Authority - G4: (email protection)
  * Symantec Class 1 Public Primary Certification Authority - G6: (email protection)
  * Symantec Class 2 Public Primary Certification Authority - G4: (email protection)
  * Symantec Class 2 Public Primary Certification Authority - G6: (email protection)
  * TrustCor ECA-1: (email protection, server auth)
  * TrustCor RootCert CA-1: (email protection, server auth)
  * TrustCor RootCert CA-2: (email protection, server auth)
  * TUBITAK Kamu SM SSL Kok Sertifikasi - Surum 1: (server auth)
* Thu Mar 31 2016 meissner@suse.com
- updated to 2.7 (bsc#973042)
- renamed: diff-from-upstream-2.2.patch -> diff-from-upstream-2.7.patch
- Removed server trust from:
  AC Raíz Certicámara S.A.
  ComSign Secured CA
  NetLock Uzleti (Class B) Tanusitvanykiado
  NetLock Business (Class B) Root
  NetLock Expressz (Class C) Tanusitvanykiado
  TC TrustCenter Class 3 CA II
  TURKTRUST Certificate Services Provider Root 1
  TURKTRUST Certificate Services Provider Root 2
  Equifax Secure Global eBusiness CA-1
  Verisign Class 4 Public Primary Certification Authority G3
- enable server trust
  Actalis Authentication Root CA
- Deleted CAs:
  AOL CA
  A Trust nQual 03
  Buypass Class 3 CA 1
  CA Disig
  Digital Signature Trust Co Global CA 1
  Digital Signature Trust Co Global CA 3
  E Guven Kok Elektronik Sertifika Hizmet Saglayicisi
  NetLock Expressz (Class C) Tanusitvanykiado
  NetLock Kozjegyzoi (Class A) Tanusitvanykiado
  NetLock Minositett Kozjegyzoi (Class QA) Tanusitvanykiado
  NetLock Uzleti (Class B) Tanusitvanykiado
  SG TRUST SERVICES RACINE
  Staat der Nederlanden Root CA
  TC TrustCenter Class 2 CA II
  TC TrustCenter Universal CA I
  TDC Internet Root CA
  UTN DATACorp SGC Root CA
  Verisign Class 1 Public Primary Certification Authority - G2
  Verisign Class 3 Public Primary Certification Authority
  Verisign Class 3 Public Primary Certification Authority - G2
- New added CAs:
  CA WoSign ECC Root
  Certification Authority of WoSign
  Certification Authority of WoSign G2
  Certinomis - Root CA
  Certum Trusted Network CA 2
  CFCA EV ROOT
  COMODO RSA Certification Authority
  DigiCert Assured ID Root G2
  DigiCert Assured ID Root G3
  DigiCert Global Root G2
  DigiCert Global Root G3
  DigiCert Trusted Root G4
  Entrust Root Certification Authority - EC1
  Entrust Root Certification Authority - G2
  GlobalSign
  GlobalSign
  IdenTrust Commercial Root CA 1
  IdenTrust Public Sector Root CA 1
  OISTE WISeKey Global Root GB CA
  QuoVadis Root CA 1 G3
  QuoVadis Root CA 2 G3
  QuoVadis Root CA 3 G3
  Staat der Nederlanden EV Root CA
  Staat der Nederlanden Root CA - G3
  S-TRUST Universal Root CA
  SZAFIR ROOT CA2
  TÜRKTRUST Elektronik Sertifika Hizmet Sağlayıcısı H5
  TÜRKTRUST Elektronik Sertifika Hizmet Sağlayıcısı H6
  USERTrust ECC Certification Authority
  USERTrust RSA Certification Authority
  沃通根证书
* Wed Jan 14 2015 meissner@suse.com
- diff-from-upstream-2.2.patch:
  Temporary reenable some root ca trusts, as openssl/gnutls
  have trouble using intermediates as root CA.
  - GTE CyberTrust Global Root
  - Thawte Server CA
  - Thawte Premium Server CA
  - ValiCert Class 1 VA
  - ValiCert Class 2 VA
  - RSA Root Certificate 1
  - Entrust.net Secure Server CA
  - America Online Root Certification Authority 1
  - America Online Root Certification Authority 2
* Mon Jan 12 2015 meissner@suse.com
- Updated to 2.2 (bnc#888534)
  - The following CAs were removed:
    + America_Online_Root_Certification_Authority_1
    + America_Online_Root_Certification_Authority_2
    + GTE_CyberTrust_Global_Root
    + Thawte_Premium_Server_CA
    + Thawte_Server_CA
  - The following CAs were added:
    + COMODO_RSA_Certification_Authority
    codeSigning emailProtection serverAuth
    + GlobalSign_ECC_Root_CA_-_R4
    codeSigning emailProtection serverAuth
    + GlobalSign_ECC_Root_CA_-_R5
    codeSigning emailProtection serverAuth
    + USERTrust_ECC_Certification_Authority
    codeSigning emailProtection serverAuth
    + USERTrust_RSA_Certification_Authority
    codeSigning emailProtection serverAuth
    + VeriSign-C3SSA-G2-temporary-intermediate-after-1024bit-removal
  - The following CAs were changed:
    + Equifax_Secure_eBusiness_CA_1
    remote code signing and https trust, leave email trust
    + Verisign_Class_3_Public_Primary_Certification_Authority_-_G2
    only trust emailProtection
* Tue Aug 26 2014 meissner@suse.com
- Updated to 2.1 (bnc#888534)
- The following 1024-bit CA certificates were removed
  - Entrust.net Secure Server Certification Authority
  - ValiCert Class 1 Policy Validation Authority
  - ValiCert Class 2 Policy Validation Authority
  - ValiCert Class 3 Policy Validation Authority
  - TDC Internet Root CA
- The following CA certificates were added:
  - Certification Authority of WoSign
  - CA 沃通根证书
  - DigiCert Assured ID Root G2
  - DigiCert Assured ID Root G3
  - DigiCert Global Root G2
  - DigiCert Global Root G3
  - DigiCert Trusted Root G4
  - QuoVadis Root CA 1 G3
  - QuoVadis Root CA 2 G3
  - QuoVadis Root CA 3 G3
- The Trust Bits were changed for the following CA certificates
  - Class 3 Public Primary Certification Authority
  - Class 3 Public Primary Certification Authority
  - Class 2 Public Primary Certification Authority - G2
  - VeriSign Class 2 Public Primary Certification Authority - G3
  - AC Raíz Certicámara S.A.
  - NetLock Uzleti (Class B) Tanusitvanykiado
  - NetLock Expressz (Class C) Tanusitvanykiado
- certdata-temporary-1024.patch: restore some certificates removed
  from NSS as these are still used for some major sites.
  openssl is not as clever as NSS in selecting the new ones in the
  chain correctly.
* Wed Jun 18 2014 meissner@suse.com
- do not provide openssl-certs, just obsolete it.
* Tue Jun 10 2014 meissner@suse.com
- in sle11 we bumped openssl-certs version to match the NSS version,
  so provide/obsolete the current version.
* Wed Jun  4 2014 lnussel@suse.de
- updated certificates to revision 1.97 (bnc#881241)
  new: "Atos TrustedRoot 2011" (codeSigning emailProtection serverAuth)
  new: "Tugra Certification Authority" (codeSigning serverAuth)
  removed: "Firmaprofesional Root CA"
  removed: "TDC OCES Root CA"
  new: "TeliaSonera Root CA v1" (emailProtection serverAuth)
  new: "T-TeleSec GlobalRoot Class 2" (emailProtection serverAuth)
* Fri Feb 21 2014 meissner@suse.com
- updated certificates to revision 1.96 (bnc#865080)
  new:     ACCVRAIZ1.pem   (Spain) (all trusts)
  new:     SG_TRUST_SERVICES_RACINE.pem (Singapore) (email signing only)
  new:     TWCA_Global_Root_CA.pem (Taiwanese) (all trusts)
  removed: Wells_Fargo_Root_CA.pem
* Mon Dec  9 2013 meissner@suse.com
- Updated to 1.95
  Distrust a sub-ca that issued google.com certificates.
  "Distrusted AC DG Tresor SSL" (bnc#854367)
* Mon Dec  9 2013 lnussel@suse.de
- fix handling of certificates with same name (bnc#854163)
* Tue Oct 29 2013 meissner@suse.com
- Updated to 1.94
  * new: CA_Disig_Root_R1:2.9.0.195.3.154.238.80.144.110.40.crt
    server auth, code signing, email signing
  * new: CA_Disig_Root_R2:2.9.0.146.184.136.219.176.138.193.99.crt
    server auth, code signing, email signing
  * new: China_Internet_Network_Information_Center_EV_Certificates_Root:2.4.72.159.0.1.crt
    server auth
  * changed: Digital_Signature_Trust_Co._Global_CA_1:2.4.54.112.21.150.crt
    removed code signing and server auth abilities
  * changed: Digital_Signature_Trust_Co._Global_CA_3:2.4.54.110.211.206.crt
    removed code signing and server auth abilities
  * new: D-TRUST_Root_Class_3_CA_2_2009:2.3.9.131.243.crt
    server auth
  * new: D-TRUST_Root_Class_3_CA_2_EV_2009:2.3.9.131.244.crt
    server auth
  * removed: Entrust.net_Premium_2048_Secure_Server_CA:2.4.56.99.185.102.crt
  * new:     Entrust.net_Premium_2048_Secure_Server_CA:2.4.56.99.222.248.crt
    I think the missing flags were adjusted.
  * removed: Equifax_Secure_eBusiness_CA_2:2.4.55.112.207.181.crt
  * new: PSCProcert:2.1.11.crt
    server auth, code signing, email signing
  * new: Swisscom_Root_CA_2:2.16.30.158.40.232.72.242.229.239.195.124.74.30.90.24.103.182.crt
    server auth, code signing, email signing
  * new: Swisscom_Root_EV_CA_2:2.17.0.242.250.100.226.116.99.211.141.253.16.29.4.31.118.202.88.crt
    server auth, code signing
  * changed: TC_TrustCenter_Universal_CA_III:2.14.99.37.0.1.0.2.20.141.51.21.2.228.108.244.crt
    removed all abilities
  * new: TURKTRUST_Certificate_Services_Provider_Root_2007:2.1.1.crt
    server auth, code signing
  * changed: TWCA_Root_Certification_Authority:2.1.1.crt
    added code signing ability
- removed temporary Entrust.net_Premium_2048_Secure_Server_CA.p11-kit override.
* Mon Aug 19 2013 lnussel@suse.de
- update Entrust root attributes to new format used by p11-kit
* Wed Jul 24 2013 lnussel@suse.de
- remove superfluous double quotes from certificate names
* Wed Jul 24 2013 lnussel@suse.de
- add fake basic contraints to Entrust root so p11-kit export the cert
  (bnc#829471)
- add nssckbi.h that matches certdata.txt; make sure package has the
  correct version number which is currently 1.93. No actual content
  change in certdata.txt compared to 1.85, it's just that the
  versioning scheme changed.
* Thu Jun 27 2013 lnussel@suse.de
- use certdata2pem.py from Fedora to extract all certs
* Fri Jun 21 2013 lnussel@suse.de
- use correct 'anchors' subdirectory
* Wed Jun 19 2013 lnussel@suse.de
- new location of CA certificate anchors is
  /usr/share/ca-certificates/anchors
* Thu Jan  3 2013 idonmez@suse.com
- update certificates to revision 1.87 (bnc#796628)
  * new "EE Certification Centre Root CA"
  * new "T-TeleSec GlobalRoot Class 3"
  * revoke mis-issued intermediate CAs from TURKTRUST
* Wed Oct 10 2012 meissner@suse.com
- updated certificates to revision 1.85 (bnc#783509)
  * new "Actalis Authentication Root CA"
  * new "Trustis FPS Root CA"
  * new "StartCom Certification Authority"
  * new "StartCom Certification Authority G2"
  * new "Buypass Class 2 Root CA"
  * new "Buypass Class 3 Root CA"
  * updated: "Sonera Class2 CA": remove code-signing
  * updated: "thawte Primary Root CA": added code-signing
  * updated: "Trustis_FPS_Root_CA.pem": added code-signing
  * updated: VeriSign Class 3 Public Primary Certification Authority - G5":
    added code-signing, email-protection
* Thu May  3 2012 lnussel@suse.de
- update certificates to revision 1.83 (bnc#760503)
  * new: EC_ACC.pem
  * new: Hellenic_Academic_and_Research_Institutions_RootCA_2011.pem
  * new: Security_Communication_RootCA2.pem
  * removed: TC_TrustCenter_Germany_Class_2_CA.pem
  * removed: TC_TrustCenter_Germany_Class_3_CA.pem
  * removed: Verisign_Class_1_Public_Primary_Certification_Authority.1.pem
  * removed: Verisign_Class_2_Public_Primary_Certification_Authority.pem
  * removed: Verisign_Class_4_Public_Primary_Certification_Authority_G2.pem
- license change to MPL-2.0
* Fri Jan 13 2012 cfarrell@suse.com
- license update: MPL-1.1 or GPL-2.0+ or LGPL-2.1+
  SPDX format and correct GPL and LGPL tags to include or later
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug 31 2011 lnussel@suse.de
- update certificates to revision 1.76
  * new: Go_Daddy_Root_Certificate_Authority_G2.pem
  * new: Starfield_Root_Certificate_Authority_G2.pem
  * new: Starfield_Services_Root_Certificate_Authority_G2.pem
  * new: AffirmTrust_Commercial.pem
  * new: AffirmTrust_Networking.pem
  * new: AffirmTrust_Premium.pem
  * new: AffirmTrust_Premium_ECC.pem
  * new: Certum_Trusted_Network_CA.pem
  * new: Certinomis_Autorit_Racine.pem
  * new: Root_CA_Generalitat_Valenciana.pem
  * new: A_Trust_nQual_03.pem
  * new: TWCA_Root_Certification_Authority.pem
  * removed: DigiNotar_Root_CA.pem (bnc#714931)
* Mon Jan 31 2011 lnussel@suse.de
- update certificates to revision 1.70
  * new: AddTrust_Qualified_Certificates_Root.pem
  * new: Autoridad_de_Certificacion_Firmaprofesional_CIF_A62634068.pem
  * new: Chambers_of_Commerce_Root_2008.pem
  * new: Global_Chambersign_Root_2008.pem
  * new: Izenpe_com.pem
  * new: TC_TrustCenter_Universal_CA_III.pem
* Mon Sep 27 2010 lnussel@suse.de
- update certificates to revision 1.65
  * new: E_Guven_Kok_Elektronik_Sertifika_Hizmet_Saglayicisi.pem
  * new: GlobalSign_Root_CA_R3.pem
  * new: Microsec_e_Szigno_Root_CA_2009.pem
  * new: Verisign_Class_1_Public_Primary_Certification_Authority.1.pem
  * new: Verisign_Class_3_Public_Primary_Certification_Authority.1.pem
* Fri May 21 2010 lnussel@suse.de
- update certificates to revision 1.64
  * removed "RSA Security 1024 V3" certificate
* Thu Apr  8 2010 lnussel@suse.de
- require ca-certificates also for postun
* Thu Apr  1 2010 lnussel@suse.de
- don't output trusted certs by default as it's not supported by
  gnutls yet and pidgin scans /etc/ssl/certs
* Thu Apr  1 2010 lnussel@suse.de
- update certificates to revision 1.62
* Fri Mar 26 2010 lnussel@suse.de
- extract trustbits as comment as Fedora does
- convert to trusted certificates in spec file instead
* Thu Mar 25 2010 lnussel@suse.de
- rename to ca-certificates-mozilla
- output trusted certificates
- use utf8 in file names
* Tue Feb  2 2010 lnussel@suse.de
- update certificates to revision 1.57
- add script to compare with previous certificates
* Wed Sep 30 2009 lnussel@suse.de
- update certifiates to cvs revision 1.56
- exclude certficates that are not trusted for identifying web sites
* Tue Dec  2 2008 cfarrell@suse.de
- Add openssl-certs.COPYING to fix bnc#441356
* Thu Oct  9 2008 lnussel@suse.de
- use certificates from MozillaFirefox
* Wed Jul  9 2008 mkoenig@suse.de
- split out the CA root certificates from the openssl certs
  subpackage into a package of its own.
